<meta charset='utf-8'>
<h1 align='center'>Qfunction</h1>
<p align='center'>
<img height='200px' width='200px' src='/img/q_logo.png'>
<br/>
<a href="https://github.com/perseu912"><img title="Autor" src="https://img.shields.io/badge/Autor-reinan_br-blue.svg?style=for-the-badge&logo=github"></a>
<br/>
<a href='http://dgp.cnpq.br/dgp/espelhogrupo/0180330616769073'><img src='https://shields.io/badge/cnpq-grupo_de_fisica_computacional_ifsertao--pe-blueviolet?logo=appveyor&style=for-the-badge'></a>
<br/>
<label>
<!-- github dados -->
<a href='https://python.org'><img src='https://img.shields.io/github/pipenv/locked/python-version/gpftc/covid_br'></a>
<a href='#'><img src='https://img.shields.io/github/languages/code-size/gpftc/covid_br'></a>
<a href='#'><img src='https://img.shields.io/github/commit-activity/m/gpftc/covid_br'></a>
<a href='#'><img src='https://img.shields.io/github/last-commit/gpftc/covid_br'></a>
<br/>
<!-- sites de pacotes -->
<a href='https://pypi.org/project/qfunction/'><img src='https://img.shields.io/pypi/v/qfunction'></a>
<a href='#'><img src='https://img.shields.io/pypi/wheel/qfunction'></a>
<a href='#'><img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dd/covidbr"></a>
<a href='#'><img src='https://img.shields.io/pypi/implementation/covidbr'></a>
<br/>
<!-- outros premios e analises -->
<a href='#'><img alt="CodeFactor Grade" src="https://img.shields.io/codefactor/grade/github/gpftc/covid_br?logo=codefactor">
</a>
<!-- redes sociais -->
<br/>
<a href='https://instagram.com/gpftc_ifsfertao/'><img src='https://shields.io/badge/insta-gpftc_ifsertao-violet?logo=instagram&style=flat'></a>
<label>
</p>
<p align='center'> <b>Library for data mining about covid-19 in brazilian cities 📈📊📚</b></p>
